/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#ifndef SQUID_SRC_FS_MODULE_H
#define SQUID_SRC_FS_MODULE_H

namespace Fs
{

void Init();

} // namespace Fs

#endif /* SQUID_SRC_FS_MODULE_H */

